<?php
/**
 * polish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Grzegorz Żur <grzegorz.zur@gmail.com>
 * @author Mariusz Kujawski <marinespl@gmail.com>
 * @author Maciej Kurczewski <pipijajko@gmail.com>
 * @author Sławomir Boczek <slawkens@gmail.com>
 * @author sleshek@wp.pl
 * @author Leszek Stachowski <shazarre@gmail.com>
 * @author maros <dobrimaros@yahoo.pl>
 * @author Grzegorz Widła <dzesdzes@gmail.com>
 * @author Łukasz Chmaj <teachmeter@gmail.com>
 * @author Begina Felicysym <begina.felicysym@wp.eu>
 * @author Aoi Karasu <aoikarasu@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Edytuj stronę';
$lang['btn_source']            = 'Pokaż źródło strony';
$lang['btn_show']              = 'Pokaż stronę';
$lang['btn_create']            = 'Utwórz stronę';
$lang['btn_search']            = 'Szukaj';
$lang['btn_save']              = 'Zapisz';
$lang['btn_preview']           = 'Podgląd';
$lang['btn_top']               = 'Do góry';
$lang['btn_newer']             = '<< nowsze';
$lang['btn_older']             = 'starsze >>';
$lang['btn_revs']              = 'Poprzednie wersje';
$lang['btn_recent']            = 'Ostatnie zmiany';
$lang['btn_upload']            = 'Wyślij';
$lang['btn_cancel']            = 'Anuluj';
$lang['btn_index']             = 'Indeks';
$lang['btn_secedit']           = 'Edytuj';
$lang['btn_login']             = 'Zaloguj';
$lang['btn_logout']            = 'Wyloguj';
$lang['btn_admin']             = 'Administracja';
$lang['btn_update']            = 'Aktualizuj';
$lang['btn_delete']            = 'Usuń';
$lang['btn_back']              = 'Wstecz';
$lang['btn_backlink']          = 'Odnośniki';
$lang['btn_backtomedia']       = 'Powrót do wyboru pliku';
$lang['btn_subscribe']         = 'Subskrybuj zmiany';
$lang['btn_profile']           = 'Aktualizuj profil';
$lang['btn_reset']             = 'Resetuj';
$lang['btn_resendpwd']         = 'Podaj nowe hasło';
$lang['btn_draft']             = 'Edytuj szkic';
$lang['btn_recover']           = 'Przywróć szkic';
$lang['btn_draftdel']          = 'Usuń szkic';
$lang['btn_revert']            = 'Przywróć';
$lang['btn_register']          = 'Zarejestruj się!';
$lang['btn_apply']             = 'Zastosuj';
$lang['btn_media']             = 'Menadżer multimediów';
$lang['loggedinas']            = 'Zalogowany jako';
$lang['user']                  = 'Użytkownik';
$lang['pass']                  = 'Hasło';
$lang['newpass']               = 'Nowe hasło';
$lang['oldpass']               = 'Potwierdź aktualne hasło';
$lang['passchk']               = 'Powtórz hasło';
$lang['remember']              = 'Zapamiętaj';
$lang['fullname']              = 'Imię i nazwisko';
$lang['email']                 = 'E-mail';
$lang['profile']               = 'Profil użytkownika';
$lang['badlogin']              = 'Nazwa użytkownika lub hasło są nieprawidłowe.';
$lang['minoredit']             = 'Mniejsze zmiany';
$lang['draftdate']             = 'Czas zachowania szkicu';
$lang['nosecedit']             = 'Strona została zmodyfikowana, sekcje zostały zmienione. Załadowano całą stronę.';
$lang['regmissing']            = 'Wypełnij wszystkie pola.';
$lang['reguexists']            = 'Użytkownik o tej nazwie już istnieje.';
$lang['regsuccess']            = 'Utworzono użytkownika. Hasło zostało przesłane pocztą.';
$lang['regsuccess2']           = 'Utworzono użytkownika.';
$lang['regmailfail']           = 'Wystąpił błąd przy wysyłaniu hasła pocztą!';
$lang['regbadmail']            = 'Adres e-mail jest nieprawidłowy!';
$lang['regbadpass']            = 'Hasła nie są identyczne, spróbuj ponownie.';
$lang['regpwmail']             = 'Twoje hasło do DokuWiki';
$lang['reghere']               = 'Nie masz jeszcze konta? Zdobądź je';
$lang['profna']                = 'To wiki nie pozwala na zmianę profilu.';
$lang['profnochange']          = 'Żadnych zmian, nic do zrobienia.';
$lang['profnoempty']           = 'Pusta nazwa lub adres e-mail nie dozwolone.';
$lang['profchanged']           = 'Zaktualizowano profil użytkownika.';
$lang['pwdforget']             = 'Nie pamiętasz hasła? Zdobądź nowe!';
$lang['resendna']              = 'To wiki nie pozwala na powtórne przesyłanie hasła.';
$lang['resendpwd']             = 'Podaj nowe hasło dla';
$lang['resendpwdmissing']      = 'Wypełnij wszystkie pola.';
$lang['resendpwdnouser']       = 'Nie można znaleźć tego użytkownika w bazie danych.';
$lang['resendpwdbadauth']      = 'Błędny kod autoryzacji! Upewnij się, że użyłeś(aś) właściwego odnośnika.';
$lang['resendpwdconfirm']      = 'Prośba o potwierdzenie została przesłana pocztą.';
$lang['resendpwdsuccess']      = 'Nowe hasło zostało wysłane pocztą.';
$lang['license']               = 'Wszystkie treści w tym wiki, którym nie przyporządkowano licencji, podlegają licencji:';
$lang['licenseok']             = 'Uwaga: edytując tę stronę zgadzasz się na publikowanie jej treści pod licencją:';
$lang['searchmedia']           = 'Szukaj pliku o nazwie:';
$lang['searchmedia_in']        = 'Szukaj w  %s';
$lang['txt_upload']            = 'Wybierz plik do wysłania';
$lang['txt_filename']          = 'Nazwa pliku (opcjonalnie)';
$lang['txt_overwrt']           = 'Nadpisać istniejący plik?';
$lang['maxuploadsize']         = 'Maksymalny rozmiar wysyłanych danych wynosi %s dla jednego pliku.';
$lang['lockedby']              = 'Aktualnie zablokowane przez';
$lang['lockexpire']            = 'Blokada wygasa';
$lang['js']['willexpire']      = 'Twoja blokada edycji tej strony wygaśnie w ciągu minuty. \nW celu uniknięcia konfliktów użyj przycisku podglądu aby odnowić blokadę.';
$lang['js']['notsavedyet']     = 'Nie zapisane zmiany zostaną utracone.
Czy na pewno kontynuować?';
$lang['js']['searchmedia']     = 'Szukaj plików';
$lang['js']['keepopen']        = 'Nie zamykaj okna po wyborze';
$lang['js']['hidedetails']     = 'Ukryj szczegóły';
$lang['js']['mediatitle']      = 'Ustawienia odnośników';
$lang['js']['mediadisplay']    = 'Typ odnośnika';
$lang['js']['mediaalign']      = 'Położenie';
$lang['js']['mediasize']       = 'Rozmiar grafiki';
$lang['js']['mediatarget']     = 'Cel odnośnika';
$lang['js']['mediaclose']      = 'Zamknij';
$lang['js']['mediainsert']     = 'Wstaw';
$lang['js']['mediadisplayimg'] = 'Pokaż grafikę';
$lang['js']['mediadisplaylnk'] = 'Pokaż tylko odnośnik.';
$lang['js']['mediasmall']      = 'Mały rozmiar';
$lang['js']['mediamedium']     = 'Średni rozmiar';
$lang['js']['medialarge']      = 'Duży rozmiar';
$lang['js']['mediaoriginal']   = 'Wersja oryginalna';
$lang['js']['medialnk']        = 'Odnośnik do strony ze szczegółami';
$lang['js']['mediadirect']     = 'Bezpośredni odnośnik do oryginału';
$lang['js']['medianolnk']      = 'Bez odnośnika';
$lang['js']['medianolink']     = 'Nie ustawiaj odnośnika do grafiki';
$lang['js']['medialeft']       = 'Ustaw położenie po lewej stronie.';
$lang['js']['mediaright']      = 'Ustaw położenie po prawej stronie.';
$lang['js']['mediacenter']     = 'Ustaw położenie po środku.';
$lang['js']['medianoalign']    = 'Nie ustawiaj położenia.';
$lang['js']['nosmblinks']      = 'Odnośniki do zasobów sieci Windows działają tylko w przeglądarce Internet Explorer.
Możesz skopiować odnośnik.';
$lang['js']['linkwiz']         = 'Tworzenie odnośników';
$lang['js']['linkto']          = 'Link do';
$lang['js']['del_confirm']     = 'Czy na pewno usunąć?';
$lang['js']['restore_confirm'] = 'Naprawdę przywrócić tą wersję?';
$lang['js']['media_diff']      = 'Pokaż różnice:';
$lang['js']['media_diff_both'] = 'Obok siebie';
$lang['js']['media_diff_opacity'] = 'Przezroczystość';
$lang['js']['media_diff_portions'] = 'Przesunięcie';
$lang['js']['media_select']    = 'Wybierz pliki...';
$lang['js']['media_upload_btn'] = 'Przesłanie plików';
$lang['js']['media_done_btn']  = 'Zrobione';
$lang['js']['media_drop']      = 'Upuść tutaj pliki do przesłania';
$lang['js']['media_cancel']    = 'usuń';
$lang['js']['media_overwrt']   = 'Nadpisz istniejące pliki';
$lang['rssfailed']             = 'Wystąpił błąd przy pobieraniu tych danych: ';
$lang['nothingfound']          = 'Nic nie znaleziono.';
$lang['mediaselect']           = 'Wysyłanie pliku';
$lang['fileupload']            = 'Wysyłanie pliku';
$lang['uploadsucc']            = 'Wysyłanie powiodło się!';
$lang['uploadfail']            = 'Błąd wysyłania pliku. Czy prawa do katalogów są poprawne?';
$lang['uploadwrong']           = 'Wysyłanie zabronione. Nie można wysłać plików z takim rozszerzeniem';
$lang['uploadexist']           = 'Plik już istnieje, nie wykonano operacji.';
$lang['uploadbadcontent']      = 'Typ pliku "%s" nie odpowiadał jego rozszerzeniu.';
$lang['uploadspam']            = 'Plik zablokowany przez filtr antyspamowy.';
$lang['uploadxss']             = 'Plik zablokowany ze względu na podejrzaną zawartość.';
$lang['uploadsize']            = 'Plik jest za duży (maksymalny rozmiar %s)';
$lang['deletesucc']            = 'Plik "%s" został usunięty.';
$lang['deletefail']            = 'Plik "%s" nie został usunięty, sprawdź uprawnienia.';
$lang['mediainuse']            = 'Plik "%s" nie został usunięty, ponieważ jest używany.';
$lang['namespaces']            = 'Katalogi';
$lang['mediafiles']            = 'Dostępne pliki';
$lang['accessdenied']          = 'Nie masz uprawnień, żeby wyświetlić tę stronę.';
$lang['mediausage']            = 'Użyj następującej składni w odnośniku do tego pliku:';
$lang['mediaview']             = 'Pokaż oryginalny plik';
$lang['mediaroot']             = 'główny';
$lang['mediaupload']           = 'Umieść plik w aktualnym katalogu. Aby utworzyć podkatalogi, poprzedź nazwę pliku nazwami katalogów oddzielonymi dwukropkami.';
$lang['mediaextchange']        = 'Rozszerzenie pliku zmieniono z .%s na .%s!';
$lang['reference']             = 'Odnośniki do';
$lang['ref_inuse']             = 'Ten plik nie może być usunięty, ponieważ jest używany na następujących stronach:';
$lang['ref_hidden']            = 'Odnośniki mogą znajdować się na stronach, do których nie masz uprawnień.';
$lang['hits']                  = 'trafień';
$lang['quickhits']             = 'Pasujące hasła';
$lang['toc']                   = 'Spis treści';
$lang['current']               = 'aktualna';
$lang['yours']                 = 'Twoja wersja';
$lang['diff']                  = 'Pokaż różnice między wersjami';
$lang['diff2']                 = 'Pokaż różnice między zaznaczonymi wersjami';
$lang['difflink']              = 'Odnośnik do tego porównania';
$lang['diff_type']             = 'Zobacz różnice:';
$lang['diff_inline']           = 'W linii';
$lang['diff_side']             = 'Jeden obok drugiego';
$lang['line']                  = 'Linia';
$lang['breadcrumb']            = 'Ślad';
$lang['youarehere']            = 'Jesteś tutaj';
$lang['lastmod']               = 'ostatnio zmienione';
$lang['by']                    = 'przez';
$lang['deleted']               = 'usunięto';
$lang['created']               = 'utworzono';
$lang['restored']              = 'przywrócono poprzednią wersję (%s)';
$lang['external_edit']         = 'edycja zewnętrzna';
$lang['summary']               = 'Opis zmian';
$lang['noflash']               = 'Plugin <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> jest niezbędny do obejrzenia tej zawartości.';
$lang['download']              = 'Pobierz zrzut';
$lang['tools']                 = 'Narzędzia';
$lang['user_tools']            = 'Narzędzia użytkownika';
$lang['site_tools']            = 'Narzędzia witryny';
$lang['page_tools']            = 'Narzędzia strony';
$lang['skip_to_content']       = 'przejście do zawartości';
$lang['mail_newpage']          = 'Strona dodana:';
$lang['mail_changed']          = 'Strona zmieniona:';
$lang['mail_subscribe_list']   = 'Zmienione strony w katalogu:';
$lang['mail_new_user']         = 'Nowy użytkownik:';
$lang['mail_upload']           = 'Umieszczono plik:';
$lang['changes_type']          = 'Zobacz zmiany';
$lang['pages_changes']         = 'Strony';
$lang['media_changes']         = 'Pliki multimediów';
$lang['both_changes']          = 'Zarówno strony jak i pliki multimediów';
$lang['qb_bold']               = 'Pogrubienie';
$lang['qb_italic']             = 'Pochylenie';
$lang['qb_underl']             = 'Podkreślenie';
$lang['qb_code']               = 'Kod źródłowy';
$lang['qb_strike']             = 'Przekreślenie';
$lang['qb_h1']                 = 'Nagłówek 1 stopnia';
$lang['qb_h2']                 = 'Nagłówek 2 stopnia';
$lang['qb_h3']                 = 'Nagłówek 3 stopnia';
$lang['qb_h4']                 = 'Nagłówek 4 stopnia';
$lang['qb_h5']                 = 'Nagłówek 5 stopnia';
$lang['qb_h']                  = 'Nagłówek';
$lang['qb_hs']                 = 'Wybierz nagłówek';
$lang['qb_hplus']              = 'Nagłówek wyższego stopnia';
$lang['qb_hminus']             = 'Nagłówek niższego stopnia';
$lang['qb_hequal']             = 'Nagłówek tego samego stopnia';
$lang['qb_link']               = 'Odnośnik wewnętrzny';
$lang['qb_extlink']            = 'Odnośnik zewnętrzny';
$lang['qb_hr']                 = 'Linia pozioma';
$lang['qb_ol']                 = 'Numeracja';
$lang['qb_ul']                 = 'Wypunktowanie';
$lang['qb_media']              = 'Dodaj obrazek lub inny plik';
$lang['qb_sig']                = 'Wstaw podpis';
$lang['qb_smileys']            = 'Emotikony';
$lang['qb_chars']              = 'Znaki specjalne';
$lang['upperns']               = 'Skok piętro wyżej';
$lang['admin_register']        = 'Dodawanie użytkownika';
$lang['metaedit']              = 'Edytuj metadane';
$lang['metasaveerr']           = 'Zapis metadanych nie powiódł się';
$lang['metasaveok']            = 'Metadane zapisano';
$lang['img_backto']            = 'Wróć do';
$lang['img_title']             = 'Tytuł';
$lang['img_caption']           = 'Nagłówek';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Nazwa pliku';
$lang['img_fsize']             = 'Rozmiar';
$lang['img_artist']            = 'Fotograf';
$lang['img_copyr']             = 'Prawa autorskie';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Aparat';
$lang['img_keywords']          = 'Słowa kluczowe';
$lang['img_width']             = 'Szerokość';
$lang['img_height']            = 'Wysokość';
$lang['img_manager']           = 'Zobacz w menadżerze multimediów';
$lang['subscr_subscribe_success'] = 'Dodano %s do listy subskrypcji %s';
$lang['subscr_subscribe_error'] = 'Błąd podczas dodawania %s do listy subskrypcji %s';
$lang['subscr_subscribe_noaddress'] = 'Brak adresu skojarzonego z twoim loginem, nie możesz zostać dodany(a) do listy subskrypcji';
$lang['subscr_unsubscribe_success'] = 'Usunięto %s z listy subskrypcji %s';
$lang['subscr_unsubscribe_error'] = 'Błąd podczas usuwania %s z listy subskrypcji %s';
$lang['subscr_already_subscribed'] = '%s jest już subskrybowany(a) przez %s';
$lang['subscr_not_subscribed'] = '%s nie jest subskrybowany(a) przez %s';
$lang['subscr_m_not_subscribed'] = 'Obecnie nie subskrybujesz bieżącej strony lub katalogu.';
$lang['subscr_m_new_header']   = 'Dodaj subskrypcję';
$lang['subscr_m_current_header'] = 'Aktualne subskrypcje';
$lang['subscr_m_unsubscribe']  = 'Zrezygnuj z subskrypcji';
$lang['subscr_m_subscribe']    = 'Subskrybuj';
$lang['subscr_m_receive']      = 'Otrzymuj';
$lang['subscr_style_every']    = 'email przy każdej zmianie';
$lang['authmodfailed']         = 'Błąd uwierzytelnienia. Powiadom administratora tego wiki.';
$lang['authtempfail']          = 'Uwierzytelnienie użytkownika jest w tej chwili niemożliwe. Jeśli ta sytuacja się powtórzy, powiadom administratora tego wiki.';
$lang['authpwdexpire']         = 'Twoje hasło wygaśnie za %d dni. Należy je zmienić w krótkim czasie.';
$lang['i_chooselang']          = 'Wybierz język';
$lang['i_installer']           = 'Instalator DokuWiki';
$lang['i_wikiname']            = 'Nazwa Wiki';
$lang['i_enableacl']           = 'Włącz mechanizm uprawnień ACL (zalecane)';
$lang['i_superuser']           = 'Administrator';
$lang['i_problems']            = 'Instalator napotkał poniższe problemy. Nie można kontynuować póki nie zostaną usunięte.';
$lang['i_modified']            = 'Ze względów bezpieczeństwa, ten skrypt działa tylko z nową i niezmodyfikowaną instalacją DokuWiki.
Aby uruchomić instalator ponownie, rozpakuj archiwum DokuWiki lub zapoznaj się z <a href="http://dokuwiki.org/install">instrukcją instalacji Dokuwiki</a>';
$lang['i_funcna']              = 'Funkcja PHP <code>%s</code> jest niedostępna.';
$lang['i_phpver']              = 'Wersja PHP <code>%s</code> jest niższa od wymaganej <code>%s</code>. Zaktualizuj instalację PHP.';
$lang['i_permfail']            = 'DokuWiki nie ma prawa zapisu w katalogu <code>%s</code>. Zmień uprawnienia zapisu dla tego katalogu!';
$lang['i_confexists']          = '<code>%s</code> już istnieje';
$lang['i_writeerr']            = 'Nie można utworzyć <code>%s</code>. Sprawdź uprawnienia do katalogu lub pliku i stwórz plik ręcznie.';
$lang['i_badhash']             = 'nierozpoznany lub zmodyfikowany plik dokuwiki.php (skrót=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - nieprawidłowa wartość lub jej brak';
$lang['i_success']             = 'Konfiguracja pomyślnie zakończona. Możesz teraz usunąć plik install.php. Przejdź do <a href="doku.php?id=wiki:welcome">Twojego nowego DokuWiki</a>.';
$lang['i_failure']             = 'Podczas zapisu plików konfiguracyjnych wystąpiły błędy. Musisz usunąć wszystkie problemy, zanim zaczniesz korzystać z <a href="doku.php?id=wiki:welcome">Twojego nowego DokuWiki</a>.';
$lang['i_policy']              = 'Wstępna polityka uprawnień ACL';
$lang['i_pol0']                = 'Otwarte Wiki (odczyt, zapis i dodawanie plików dla wszystkich)';
$lang['i_pol1']                = 'Publiczne Wiki (odczyt dla wszystkich, zapis i dodawanie plików tylko dla zarejestrowanych użytkowników)';
$lang['i_pol2']                = 'Zamknięte Wiki (odczyt, zapis i dodawanie plików tylko dla zarejestrowanych użytkowników)';
$lang['i_retry']               = 'Spróbuj ponownie';
$lang['i_license']             = 'Wybierz licencję, na warunkach której chcesz udostępniać treści:';
$lang['recent_global']         = 'W tej chwili przeglądasz zmiany w katalogu <b>%s</b>. Możesz przejrzeć także <a href="%s">zmiany w całym wiki</a>.';
$lang['years']                 = '%d lat temu';
$lang['months']                = '%d miesięcy temu';
$lang['weeks']                 = '%d tygodni temu';
$lang['days']                  = '%d dni temu';
$lang['hours']                 = '%d godzin temu';
$lang['minutes']               = '%d minut temu';
$lang['seconds']               = '%d sekund temu';
$lang['wordblock']             = 'Twoje ustawienia nie zostały zapisane ponieważ zawierają niedozwoloną treść (spam).';
$lang['media_uploadtab']       = 'Przesyłanie plików';
$lang['media_searchtab']       = 'Szukaj';
$lang['media_file']            = 'Plik';
$lang['media_viewtab']         = 'Widok';
$lang['media_edittab']         = 'Zmiana';
$lang['media_historytab']      = 'Historia';
$lang['media_list_thumbs']     = 'Miniatury';
$lang['media_list_rows']       = 'Wiersze';
$lang['media_sort_name']       = 'Nazwa';
$lang['media_sort_date']       = 'Data';
$lang['media_namespaces']      = 'Wybierz przestrzeń nazw';
$lang['media_files']           = 'Pliki w %s';
$lang['media_upload']          = 'Przesyłanie plików na %s';
$lang['media_search']          = 'Znajdź w %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s na %s';
$lang['media_edit']            = 'Zmień %s';
$lang['media_history']         = 'Historia dla %s';
$lang['media_meta_edited']     = 'zmienione metadane';
$lang['media_perm_read']       = 'Przepraszamy, nie masz wystarczających uprawnień do odczytu plików.';
$lang['media_perm_upload']     = 'Przepraszamy, nie masz wystarczających uprawnień do przesyłania plików.';
$lang['media_update']          = 'Prześlij nową wersję';
$lang['media_restore']         = 'Odtwórz tą wersję';
